# A nodejs logger for AWS Lambda
* Writes logs to stdout using console.log
* Logs in JSON format
* Supports log levels: DEBUG, INFO, WARN, ERROR and OFF
* Defaults to log level INFO
* Built using typescript and includes types

### Code example:
```typescript
import { APIGatewayEvent } from 'aws-lambda';
import { log } from 'pn-lambda-logger';
import { ok } from '../aws/response';

export const healthCheck = async (event: APIGatewayEvent, context: AWSLambda.Context, cb: AWSLambda.Callback) => {

  // Will not show debug messages since default log.level = INFO
  log.debug({ message: 'Debug message' });

  // Message is mandatory
  log.info({ message: 'My message' });

  // xRequestId is optional
  log.warn({ message: 'My message', xRequestId: 'some-external-id' });

  // Context and xRequestId are optional
  log.error({ message: 'My message', context, xRequestId: 'some-external-id' });

  // Context and xRequestId are optional
  log.error({ message: 'My message', context, xRequestId: 'some-external-id', customProp1: 'custom property', customProp2: 42, customProp3: { a: 'more', complex: 'property' } });

  cb(null, ok({ status: 'UP' }));
};
```

### This is the logs produced by the code above: 
```JSON
/* log.warn({ message: 'My message', xRequestId: 'some-external-id' }); */
{
  "@timestamp": 1540931318921,
  "level": "INFO",
  "message": "My message"
}

/* log.warn({ message: 'My message', xRequestId: 'some-external-id' }); */
{
  "@timestamp": 1540931318922,
  "level": "WARN",
  "message": "My message"
}

/* log.error({ message: 'My message', context, xRequestId: 'some-external-id' }); */
{
  "@timestamp": 1540931318923,
  "level": "ERROR",
  "message": "My message",
  "awsRequestId": "offline_awsRequestId_2442795498236543",
  "functionName": "postnord-retail-events-test-healthCheck",
  "functionVersion": "offline_functionVersion_for_postnord-retail-events-test-healthCheck",
  "invokedFunctionArn": "offline_invokedFunctionArn_for_postnord-retail-events-test-healthCheck",
  "logGroupName": "offline_logGroupName_for_postnord-retail-events-test-healthCheck",
  "logStreamName": "offline_logStreamName_for_postnord-retail-events-test-healthCheck",
  "memoryLimitInMB": 128,
  "remainingTime": 4997
}

/*
log.error({ message: 'My message', context, xRequestId: 'some-external-id', customProp1: 'custom property', customProp2: 42, customProp3: { a: 'more', complex: 'property' } });
*/
{
  "@timestamp": 1540931318924,
  "level": "ERROR",
  "message": "My message",
  "awsRequestId": "offline_awsRequestId_2442795498236543",
  "functionName": "postnord-retail-events-test-healthCheck",
  "functionVersion": "offline_functionVersion_for_postnord-retail-events-test-healthCheck",
  "invokedFunctionArn": "offline_invokedFunctionArn_for_postnord-retail-events-test-healthCheck",
  "logGroupName": "offline_logGroupName_for_postnord-retail-events-test-healthCheck",
  "logStreamName": "offline_logStreamName_for_postnord-retail-events-test-healthCheck",
  "memoryLimitInMB": 128,
  "remainingTime": 4996,
  "customProp1": "custom property",
  "customProp2": 42,
  "customProp3": {
    "a": "more",
    "complex": "property"
  }
}

```
 
### Setting the log level:
```typescript
  log.level = LogLevels.DEBUG;
  log.debug({ message: 'Debug message' });
```

### Mute all logs:
```typescript
  log.level = LogLevels.OFF;
```